UserData

Struct UserData 

pub struct UserData<A, T: ?Sized> { /* private fields */ }
Lua full userdata.

Use Lua::create_ud() or Context::create_ud() to create the value of this type.

Types that implement [PropertyKey]

You can pass a value of the following types for property name:

  • Reference to str.

Implementations

Source

impl<A, T: Any> UserData<A, T>

pub fn value(&self) -> &T

Returns a reference to the encapsulated value.

Source

impl<A, T: ?Sized> UserData<A, T>

pub fn get<K: PropertyKey>(&self, name: K) -> Value<'_, A>

Gets a property of this userdata.

See UserData for a list of supported value on name.

pub fn set<K: PropertyKey>(&self, name: K, value: impl Into<UnsafeValue<A>>)

Sets a property of this userdata.

Once this method is called the index operation on this userdata no longer report an error even if this userdata does not have a metatable or no __index on its metatable.

See UserData for a list of supported value on name.

Panics

If value was created from different Lua instance.

Source

impl<A> UserData<A, dyn Any>

pub fn is<T: Any>(&self) -> bool

Returns true if the encapsulated value is T.

pub fn downcast<T: Any>(&self) -> Option<&UserData<A, T>>

Attempts to downcast the userdata to a concrete type.